#!/bin/sh

# check the devices with "v4l2-ctl -list-devices"
VID_DEVICE_1=`v4l2-ctl --list-devices | grep -C1 csi1 | grep video | cut -c 2-`
VID_DEVICE_2=`v4l2-ctl --list-devices | grep -C1 csi2 | grep video | cut -c 2-`

echo ""
echo " camera device @CAM1 = $VID_DEVICE_1"
echo " camera device @CAM2 = $VID_DEVICE_2"

echo ""
echo " starting gstreamer with two BAYER Sources ..."
echo " read CAM1 from MIPI-CSI-2_CSI1 and CAM2 from MIPI-CSI-2_CSI2 with 1280 x 800"
echo " write side by side to 2560x1600 Pixel, convert to jpg and write to ar0144_col_dual_image.jpg"
echo " ============================================================================================"
echo ""
echo " configure camera with v4l2_control"
echo " =================================="

v4l2-ctl -d $VID_DEVICE_1 --set-fmt-video=pixelformat=GRBG,width=1280,height=800
v4l2-ctl -d $VID_DEVICE_1 --set-selection=target=crop,left=0,top=4,width=1280,height=800

v4l2-ctl -d $VID_DEVICE_2 --set-fmt-video=pixelformat=GRBG,width=1280,height=800
v4l2-ctl -d $VID_DEVICE_2 --set-selection=target=crop,left=0,top=4,width=1280,height=800

echo ""
echo " start gstreamer"
echo " ==============="

gst-launch-1.0 videomixer name=mix  sink_0::xpos=0 sink_0::ypos=0 sink_1::xpos=1280 sink_1::ypos=0 ! videoconvert ! jpegenc ! multifilesink location=ar0144_col_dual_image.jpg \
	v4l2src num-buffers=5 device=$VID_DEVICE_1 ! \
	video/x-bayer,format=grbg,depth=8,width=1280,height=800,framerate=30/1 ! queue ! bayer2rgbneon ! videoconvert ! mix. \
	v4l2src num-buffers=5 device=$VID_DEVICE_2 ! \
	video/x-bayer,format=grbg,depth=8,width=1280,height=800,framerate=30/1 ! queue ! bayer2rgbneon ! videoconvert ! mix.
