#!/usr/bin/env python

'''
Sample show VideoCapture via v4l2 interface for PHYTEC phyCAM-M series.
Keys:
    q    - exit
'''

# Python 2/3 compatibility
import cv2
import subprocess
import sys
import os
import time

prev_frame_time = 0
new_frame_time = 0
fps_average_count = 0
fps = 0

font                = cv2.FONT_HERSHEY_SIMPLEX
TopLeftCornerOfText = (10,30)
fontScale           = 1
fontColor           = (255,255,255)
lineType            = 2

print ("")
print ("choose you camera")
print ("=================")
print ("1 = VM-016-BW,  HD-Resolution (1280 x 720)")
print ("2 = VM-016-COL, HD-Resolution (1280 x 720)")
print ("3 = VM-017-BW,  Full-HD-Resolution (1920 x 1080)")
print ("4 = VM-017-COL, Full-HD-Resolution (1920 x 1080)")
camera_version = input("Your select = ")

if camera_version == "1":
	cam_width = 1280; cam_height = 720
	v4l2_format_param = "--set-fmt-video=pixelformat=GREY,width=1280,height=800"
	v4l2_crop_param = "--set-selection=target=crop,left=0,top=44,width="+str(cam_width)+",height="+str(cam_height)
	v4l2_ctl_param = "auto_exposure_max=1600,vertical_blanking=858"; cam_col_fmt = "Y8"
elif camera_version == "2":
	cam_width = 1280; cam_height = 720
	v4l2_format_param = "--set-fmt-video=pixelformat=GRBG,width=1280,height=800"
	v4l2_crop_param = "--set-selection=target=crop,left=0,top=44,width="+str(cam_width)+",height="+str(cam_height)
	v4l2_ctl_param = "auto_exposure_max=1600,vertical_blanking=858,autogain_digital=0,digital_gain_green_red=1200,digital_gain_green_blue=1200"; cam_col_fmt = "SGRBG8_1X8"
elif camera_version == "3":
	cam_width = 1920; cam_height = 1080
	v4l2_format_param = "--set-fmt-video=pixelformat=GREY,width=2592,height=1944"
	v4l2_crop_param = "--set-selection=target=crop,left=336,top=433,width="+str(cam_width)+",height="+str(cam_height)
	v4l2_ctl_param = "exposure=1817,analogue_gain=5000"; cam_col_fmt = "Y8"
elif camera_version == "4":
	cam_width = 1920; cam_height = 1080
	v4l2_format_param = "--set-fmt-video=pixelformat=GRBG,width=2592,height=1944"
	v4l2_crop_param = "--set-selection=target=crop,left=336,top=433,width="+str(cam_width)+",height="+str(cam_height)
	v4l2_ctl_param = "exposure=1817,analogue_gain=5000,digital_gain_red=1200,digital_gain_blue=1200"; cam_col_fmt = "SGRBG8_1X8"
else:
	print ("wrong number")
	sys.exit(0)

# read /dev/video[x] camera at CSI1
ret = subprocess.run("v4l2-ctl --list-devices | grep -C1 csi1 | grep video | cut -c 2-", shell=True, stdout=subprocess.PIPE)
CSI1_DEVICE = ret.stdout.decode()				# .decode -> convert returnvalue from byte in string
CSI1_DEVICE = CSI1_DEVICE[:-1]					# cut the "\n" at the end
CSI1_DEVICE_NUMBER = CSI1_DEVICE[10:].strip()	# .strip() -> cut the first 10 characters
print ("")
print (" camera device for CSI1 port = ", CSI1_DEVICE)

print ("")
print (" configure CSI1_Device (camera_1 port) with v4l2_control")
print (" Note: For use CSI2_Device (camera_2 port) or 2 cameras or other")
print (" resolutions, see the scripts in path ...\\gstreamer_examples\\...")
print (" ===============================================================")

subprocess.run(["v4l2-ctl", "-d", str(CSI1_DEVICE), str(v4l2_format_param)])	# set format of image
subprocess.run(["v4l2-ctl", "-d", str(CSI1_DEVICE), str(v4l2_crop_param)])		# set ROI the center of image
subprocess.run(["v4l2-ctl", "-d", str(CSI1_DEVICE), "-c", str(v4l2_ctl_param)])	# set v4l2 controls


if cam_col_fmt == "SGRBG8_1X8":
   gst_call = cv2.VideoCapture("v4l2src device="+str(CSI1_DEVICE)+" ! video/x-bayer, format=grbg, width="+str(cam_width)+", height="+str(cam_height)+" ! bayer2rgbneon ! queue ! videoconvert ! appsink", cv2.CAP_GSTREAMER)
else:
   gst_call = cv2.VideoCapture("v4l2src device="+str(CSI1_DEVICE)+" ! video/x-raw,format=GRAY8,depth=8, width="+str(cam_width)+", height="+str(cam_height)+" ! appsink", cv2.CAP_GSTREAMER)


while(True):
    ret, frame = gst_call.read()

    if fps_average_count == 10:
       new_frame_time = time.time()
       fps = 10/(new_frame_time-prev_frame_time)
       prev_frame_time = new_frame_time
       print ("fps = %3.1f"% fps, end='\r')
       fps_average_count = 0
    fps_average_count += 1
    cv2.putText(frame, "FPS: {:03.1f}".format(fps), TopLeftCornerOfText, font, fontScale, fontColor, lineType)

    cv2.resizeWindow('phyCAM - Live Image', cam_width,cam_height)
    cv2.imshow('phyCAM - Live Image',frame)
    if cv2.waitKey(1) & 0xFF == ord('q'):
        break

cap.release()
cv2.destroyAllWindows()
